@@ -9,9 +9,9 @@ from networktools.library import my_random_string
 
 from networktools.colorprint import rprint, bprint
 from networktools.path import home_path
+from abc import ABC, abstractmethod
 
-
-class BaseProtocol:
+class BaseProtocol(ABC):
     """ Class to connect to tcp port and parse GSOF messages """
     tipo = "Base"
 
@@ -45,7 +45,8 @@ class BaseProtocol:
                               station,
                               self.host,
                               path=log_path,
-                              base_level=log_level)
+                              base_level=log_level, 
+                              max_bytes=10100204)
         # manage asyncronous clients
         self.logger.info("Log para %s" % self.station)
 
@@ -73,6 +74,7 @@ class BaseProtocol:
         port = self.port
         loop = self.loop
         counter = 0
+        idc = ""
         while not self.status:
             if counter > self.max_try:
                 counter = 0
@@ -93,18 +95,14 @@ class BaseProtocol:
             except asyncio.TimeoutError as te:
                 self.logger.exception(
                     f"Tiempo fuera en intento de conexión {te}, iteracion {counter}")
-                counter += 1
-                await asyncio.sleep(10+counter)
-                continue
+                raise te
             except socket.timeout as timeout:
                 self.on_blocking()
                 self.logger.error(
                     f"Error en conexión con {host}:{port}, error: {timeout}, iteración {counter}")
                 # print("Error de socket a GSOF en conexión %s" % timeout)
-                counter += 1
                 self.status = False
-                await asyncio.sleep(10+counter)
-                continue
+                raise timeout
                 # await self.connect()
                 # raise timeout
             except socket.error as e:
@@ -116,27 +114,21 @@ class BaseProtocol:
                     #      self.station, file=sys.stderr)
                     self.logger.exception(
                         f"Error al conectar {e}, station {self.station}, iteración {counter}")
-                    counter += 1
-                    await asyncio.sleep(10+counter)
                 else:
                     # print("No se puede establecer conexión, de %s" %
                     #      self.station, file=sys.stderr)
                     self.logger.exception(
                         f"Otro tipo de error al conectar {e}, station {self.station}, iteración {counter}")
-                    counter += 1
-                    await asyncio.sleep(10+counter)
-                continue
+                raise e
             except (ConnectionResetError, ConnectionAbortedError) as conn_error:
                 self.logger.exception(
                     f"Excepción por desconexión {conn_error}")
-                continue
+                raise conn_error
             except Exception as e:
                 msg = f"Excepción no considerada e"
                 print(msg)
                 self.logger.exception(msg)
-                continue
-            await asyncio.sleep(10+counter)
-
+                raise e
         return idc
 
     # callback for create server:
@@ -161,24 +153,24 @@ class BaseProtocol:
                 except asyncio.TimeoutError as te:
                     self.logger.exception(
                         f"Tiempo fuera en intento de cerrar conexión {te}, station {self.station}")
-                    await asyncio.sleep(10)
+                    await asyncio.sleep(5)
                 except asyncio.IncompletereadError as e:
                     self.logger.exception(
                         f"Excepción por lectura incomplete  {e}, station {self.station}")
-                    await asyncio.sleep(10)
+                    await asyncio.sleep(5)
                 except asyncio.CanceledError as e:
                     self.logger.exception(
                         "Excepción por error de cancelación  {e}, station {self.station}")
-                    await asyncio.sleep(10)
+                    await asyncio.sleep(5)
                 except (ConnectionResetError, ConnectionAbortedError) as conn_error:
                     self.logger.exception(
                         "Excepción por desconexión {conn_error}, station {self.station}")
-                    await asyncio.sleep(10)
+                    await asyncio.sleep(5)
                 except Exception as e:
                     print(f"Excepción no considerada, {e}")
                     self.logger.exception(
                         f"Excepción no considerada {e}, station {self.station}")
-                    await asyncio.sleep(10)
+                    await asyncio.sleep(5)
                 self.logger.exception(
                     "Cerrando correctamente la conexión, por no heartbeat")
                 self.status = False
@@ -234,22 +226,29 @@ class BaseProtocol:
         writer = self.clients[idc]['writer']
         writer.close()
         try:
-            await wait_for(writer.wait_closed(), timeout=10)
+            writer.close()
+            await writer.wait_closed()
         except asyncio.TimeoutError as te:
             print(f"Close->Error Timeout al leer {te} bytes en {self.station}")
             self.logger.exception(
                 f"Station {self.station}, Tiempo fuera al leer en readbytes, {te}")
+            raise te
         except asyncio.IncompleteReadError as ir:
             print("Close_>Incomplete read, station {self.station}")
             self.logger.exception(
-                f"Station {self.station}, Tiempo fuera al no poder leer en close, {ir}")
+                f"""Station {self.station}, Tiempo fuera al no poder
+                leer en close, {ir}""")
+            raise ir
         except (ConnectionResetError, ConnectionAbortedError) as conn_error:
             self.logger.exception(
-                f"Close->Excepción por desconexión al intentar leer {conn_error}")
+                f"""Close->Excepción por desconexión al intentar leer
+                {conn_error}""")
+            raise conn_error
         except Exception as e:
             print("Excepción no considerada")
             self.logger.exception(
                 f"Close->Excepción no considerada al intentar leer e")
+            raise e
 
     async def stop(self):
         for idc in self.clients:
@@ -259,44 +258,43 @@ class BaseProtocol:
         future = reader.readexactly(n)
         try:
             timeout = self.timeout
-            if n > 1:
-                timeout = timeout*n
             result = await wait_for(future, timeout=timeout)
             return result
         except BrokenPipeError as be:
             print("readbytes", f"Error broken pip {be}")
-            return b''
+            raise be
         except asyncio.IncompleteReadError as ir:
             print(
                 f"Error por lectura incomplete al leer {n} bytes en {self.station}")
             self.logger.exception(
-                f"Station {self.station}, lectura incomplete al leer en readbytes, error: {ir}")
+                f"""Station {self.station}, lectura incomplete al leer
+                en readbytes, error: {ir}""")
+            raise ir
         except asyncio.TimeoutError as te:
             print(f"Error Timeout al leer {n} bytes en {self.station}")
             self.logger.exception(
                 f"Station {self.station}, Tiempo fuera al leer en readbytes, {te}")
-            if self.raise_timeout:
-                raise te
-            else:
-                return b''
+            raise te
         except asyncio.IncompleteReadError as ir:
             print(f"Incomplete read, station {self.station}")
             self.logger.exception(
                 f"Station {self.station}, Tiempo fuera al no poder leer en readbytes {n} bytes, {ir}")
-            return b''
+            raise ir
         except (ConnectionResetError, ConnectionAbortedError) as conn_error:
             self.logger.exception(
-                f"Excepción por desconexión al intentar leer {conn_error}")
-            return b''
+                f"""Excepción por desconexión al intentar leer
+                {conn_error}""")
+            raise conn_error
         except Exception as e:
             print("Excepción no considerada")
             self.logger.exception(
                 "Excepción no considerada al intentar leer {e}")
-            return b''
+            raise e
 
     async def get_message_header(self, idc):
         self.idc = idc
 
+    @abstractmethod
     async def get_records(self):
         """
         Esta corutina toma los datos en bytes y los transforma,
