@@ -91,21 +91,25 @@ class Gsof(BaseProtocol):
                 self.data_check["DATA_BYTES"] = list(self.msg_bytes+data[1:])
                 self.checksum = checksum256(self.data_check)
                 self.msg_dict["CHECKED"] = self.checksum
+            except asyncio.CancelledError as ce:
+                self.logger.exception("Get message CancelledError, %s" % ce)
+                raise ce                
             except asyncio.TimeoutError as te:
-                self.logger.exception("Get message TimeoutError, %s" % te)
-                return False
+                self.logger.exception(f"Get message TimeoutError, {te}")
+                raise te
             except asyncio.IncompleteReadError as ir:
                 print(f"Incomplete read on set header {reader}, {n} bytes")
                 self.logger.exception(
-                    f"Station {self.station}, Tiempo fuera al no poder leer en readbytes {n} bytes, {ir}")
-                return False
+                    f"""Station {self.station}, Tiempo fuera al no poder
+                    leer en readbytes {n} bytes, {ir}""")
+                raise ir
             except socket.timeout as timeout:
                 self.logger.exception(
                     f"La conexión se cerró, socket timeout {timeout}, STATION {self.station}")
                 self.on_blocking()
                 self.logger.exception("Esperando mucho tiempo")
                 self.status = False
-                return False
+                raise timeout
             except Exception as ex:
                 print("Escepcion as ex: %s" % ex)
                 self.logger.exception(
@@ -116,7 +120,7 @@ class Gsof(BaseProtocol):
                 self.logger.info(info)
                 self.logger.error(ex)
                 self.status = False
-                return False
+                raise ex
             return True
 
         except asyncio.IncompleteReadError as e:
